@@ -203,7 +203,7 @@ my_tcp_check(struct tcphdr *th, int len, u_int saddr, u_int daddr)
   if (dontchksum(saddr))
   	return 0;
   return csum_tcpudp_magic(saddr, daddr, len, IPPROTO_TCP,
-			   csum_partial((char *)th, len, 0));
+			   csum_partial((u_char *)th, len, 0));
 }
 inline u_short
 my_udp_check(void *u, int len, u_int saddr, u_int daddr)
@@ -211,7 +211,7 @@ my_udp_check(void *u, int len, u_int saddr, u_int daddr)
   if (dontchksum(saddr))
   	return 0;
   return csum_tcpudp_magic(saddr, daddr, len, IPPROTO_UDP,
-			   csum_partial((char *)u, len, 0));
+			   csum_partial((u_char *)u, len, 0));
 }
 
 #else /* !i386 */
