@@ -3,6 +3,7 @@
   Modified in Jun 99 by Nergal.
 */
 
+#include <config.h>
 #include <sys/types.h>
 #include <sys/time.h>
 #include <netinet/in.h>
@@ -378,7 +379,7 @@ static void
 ip_evictor(void)
 {
   // fprintf(stderr, "ip_evict:numpack=%i\n", numpack);
-  while (this_host->ip_frag_mem > IPFRAG_LOW_THRESH) {
+  while (this_host && this_host->ip_frag_mem > IPFRAG_LOW_THRESH) {
     if (!this_host->ipqueue)
       panic("ip_evictor: memcount");
     ip_free(this_host->ipqueue);
@@ -493,7 +494,7 @@ ip_glue(struct ipq * qp)
     return (NULL);
   }
   /* Fill in the basic details. */
-  ptr = skb;
+  ptr = (unsigned char *)skb;
   memcpy(ptr, ((unsigned char *) qp->iph), qp->ihlen);
   ptr += qp->ihlen;
   count = 0;
@@ -606,7 +607,7 @@ ip_defrag(struct ip *iph, struct sk_buff *skb)
   end = offset + ntohs(iph->ip_len) - ihl;
 
   /* Point into the IP datagram 'data' part. */
-  ptr = skb->data + ihl;
+  ptr = (unsigned char *)(skb->data + ihl);
 
   /* Is this the final fragment? */
   if ((flags & IP_MF) == 0)
