@@ -10,7 +10,8 @@
 #define IPF_NEW  2
 #define IPF_ISF  3
 
-int ip_frag_init(int);
+void ip_frag_init(int);
+void ip_frag_exit(void);
 int ip_defrag_stub(struct ip *, struct ip **);
 
 #endif /* _NIDS_IP_FRAGMENT_H */
