@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 1999 Rafal Wojtczuk <nergal@avet.com.pl>. All rights reserved.
+  Copyright (c) 1999 Rafal Wojtczuk <nergal@7bulls.com>. All rights reserved.
   See the file COPYING for license details.
 */
 
@@ -18,7 +18,7 @@ extern "C" {
 # endif
 
 # define NIDS_MAJOR 1
-# define NIDS_MINOR 23
+# define NIDS_MINOR 25
 
 enum
 {
@@ -106,6 +106,7 @@ struct tcp_stream
   int read;
   struct tcp_stream *next_free;
   void *user;
+  long ts;
 };
 
 struct nids_prm
@@ -131,6 +132,7 @@ struct nids_prm
   int queue_limit;
   int tcp_workarounds;
   pcap_t *pcap_desc;
+  int tcp_flow_timeout;
 };
 
 struct tcp_timeout
@@ -143,9 +145,13 @@ struct tcp_timeout
 
 int nids_init (void);
 void nids_register_ip_frag (void (*));
+void nids_unregister_ip_frag (void (*));
 void nids_register_ip (void (*));
+void nids_unregister_ip (void (*));
 void nids_register_tcp (void (*));
+void nids_unregister_tcp (void (*x));
 void nids_register_udp (void (*));
+void nids_unregister_udp (void (*));
 void nids_killtcp (struct tcp_stream *);
 void nids_discard (struct tcp_stream *, int);
 int nids_run (void);
