@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 1999 Rafal Wojtczuk <nergal@avet.com.pl>. All rights reserved.
+  Copyright (c) 1999 Rafal Wojtczuk <nergal@7bulls.com>. All rights reserved.
   See the file COPYING for license details.
 */
 
@@ -23,9 +23,19 @@ struct lurker_node {
 
 void nids_no_mem(char *);
 char *test_malloc(int);
-inline int before(u_int seq1, u_int seq2);
-inline int after(u_int seq1, u_int seq2);
 void register_callback(struct proc_node **procs, void (*x));
 void unregister_callback(struct proc_node **procs, void (*x));
 
+static inline int
+before(u_int seq1, u_int seq2)
+{
+  return ((int)(seq1 - seq2) < 0);
+}
+
+static inline int
+after(u_int seq1, u_int seq2)
+{
+  return ((int)(seq2 - seq1) < 0);
+}
+
 #endif /* _NIDS_UTIL_H */
